# hosts/valefar/configuration.nix (or default.nix)
{ config, lib, pkgs, modulesPath, ... }:

{
  imports = [
    # Host-specific hardware
    ./hardware.nix
    ./secrets.nix
    
    # Common modules shared across hosts
    ../../modules/common/system.nix
    ../../modules/common/users.nix
    ../../modules/common/services.nix
    
    # Services specific to this host
    #../../services/forgejo.nix

    # Common secrets
    ../../host-secrets.nix
  ];

  system.stateVersion = "24.11";
  modules.garage.enable = true;

  # pin host platform & microcode
  nixpkgs.hostPlatform               = lib.mkDefault "x86_64-linux";
  hardware.cpu.intel.updateMicrocode = lib.mkDefault
    config.hardware.enableRedistributableFirmware;

  boot.loader.grub.enable = true;
  boot.loader.grub.device = "/dev/vda";

  networking.hostName = "buer";
  networking.hostId = "1418d29e";
  networking.firewall.enable = false;
  networking.useDHCP = false;
  systemd.network.enable = true;
  systemd.network.networks."10-wan" = {
    matchConfig.Name = "ens3";
    address = [
      "103.251.165.107/24"
      "2a04:52c0:0135:48d1::2/48"
    ];
    gateway = [
      "103.251.165.1"
      "2a04:52c0:0135::1"
    ];
    dns = [
      "2a01:6340:1:20:4::10"
      "2a04:52c0:130:2a5c::10"
      "185.31.172.240"
      "5.255.125.240"
    ];
  };
  
  #boot.supportedFilesystems = [ "zfs" ];
  #boot.kernelModules = [ "nct6775" "coretemp" ];

  #services.zfs.autoScrub.enable = true;
  #services.zfs.trim.enable = true;

  environment.systemPackages = with pkgs; [
    #lm_sensors
    #code-server
  ];

  virtualisation.docker = {
    enable = true;
    enableOnBoot = true;
    package = pkgs.docker.override {
      buildGoModule = pkgs.buildGo123Module;
    };
  };
}
